package be.vmm.lucht.service;

import java.util.List;

import be.vmm.lucht.data.model.MeetPrincipe;

/**
 * Service interface voor meet principes.
 * 
 * @author vandrth
 */
public interface IMeetPrincipeService {

	/**
	 * Ophalen van alle meetprincipes.
	 * 
	 * @return List<MeetPrincipe> Lijst met alle meetprincipe objecten uit de
	 *         databank.
	 */
	List<MeetPrincipe> findAllMeetPrincipes();

	/**
	 * Ophalen van alle actieve meetprincipes.
	 * 
	 * @return List<MeetPrincipe> Lijst met alle actieve meetprincipe objecten
	 *         uit de databank.
	 */
	List<MeetPrincipe> findAllActieveMeetPrincipes();

	/**
	 * Opslaan van een nieuw meetprincipe.
	 * 
	 * @param meetPrincipe
	 *            Het meet principe dat moet opgeslagen worden.
	 * @return {@link MeetPrincipe} Het opgeslagen meet principe.
	 */
	MeetPrincipe saveMeetPrincipe(MeetPrincipe meetPrincipe);

	/**
	 * Aanpassen van een meet principe.
	 * 
	 * @param meetPrincipe
	 *            Het meet principe dat aangepast moet worden.
	 * @return {@link MeetPrincipe} Het aangepaste meet principe.
	 */
	MeetPrincipe updateMeetPrincipe(MeetPrincipe meetPrincipe);

	/**
	 * Verwijderen van een bestaande meetPrincipe.
	 * 
	 * @param meetPrincipe
	 *            Het meetPrincipe dat verwijderd moet worden.
	 * @throws DataIntegrityItemException
	 *             Wanneer er nog gerelateerde data in de databank zit.
	 */
	void deleteMeetPrincipe(MeetPrincipe meetPrincipe)
			throws DataIntegrityItemException;

}
